import { getHighlighter, isSupportedLanguage } from '@content-thing/syntax-highlighter';
import fs from "node:fs";
const HIGHLIGHT_REGEX = /(\?|&)highlight(?:&|$)/;
const EXTENSION_REGEX = /\.[^\/.]+(?=[?#]|$)/;
const POSTFIX_REGEX = /[?#].*$/;
function cleanUrl(url) {
    return url.replace(POSTFIX_REGEX, '');
}
/**
 * A Vite plugin to highlight code using Lezer.
 */
export function syntaxHighlighter() {
    let vite;
    return {
        // Run before other plugins (e.g. vite-plugin-svelte)
        enforce: 'pre',
        name: '@content-thing/vite-plugin-syntax-highlighter',
        configResolved(server) {
            vite = server;
        },
        async load(id) {
            const highlightMatch = id.match(HIGHLIGHT_REGEX);
            if (!highlightMatch)
                return;
            const [extension] = id.match(EXTENSION_REGEX) || [];
            if (!extension)
                return;
            if (!isSupportedLanguage(extension)) {
                const message = `Unable to syntax highlight ${JSON.stringify(id)}. Language "${extension}" is unsupported.`;
                if (vite.command === 'build') {
                    throw Error(message);
                }
                else {
                    vite.logger.error(message);
                }
                return;
            }
            const highlighter = await getHighlighter(extension);
            const code = fs.readFileSync(cleanUrl(id), 'utf-8');
            const highlightResult = highlighter(code);
            return `export default const tokens = JSON.parse(${JSON.stringify(JSON.stringify(highlightResult))});\n`;
        },
    };
}
//# sourceMappingURL=plugin.js.map